@@ -5,7 +5,7 @@ import re
 import simplejson
 from turbogears import validators
 
-from tgwebservices.runtime import primitives
+from tgwebservices.runtime import primitives, typedproperty
 
 namespace_expr = re.compile(r'^\{.*\}')
 
@@ -26,6 +26,8 @@ def _get_single_value(elem, itype):
         for subelem in elem.getchildren():
             items.append(_get_single_value(subelem, itemtype))
         return items
+    if isinstance(itype, typedproperty):
+        itype = itype.type
     if not isinstance(itype, type):
         itype = type(itype)
     if itype not in primitives:
@@ -100,6 +102,8 @@ def _get_json_value(value, itype):
     if isinstance(itype, list):
         itemtype = itype[0]
         return [_get_json_value(item, itemtype) for item in value]
+    elif isinstance(itype, typedproperty):
+        return _get_json_value(value, itype.type)
     elif not isinstance(itype, type):
         return _get_json_value(value, type(itype))
     elif itype not in primitives and isinstance(value, dict):
