@@ -26,7 +26,8 @@ log = logging.getLogger("tgwebservices.soap")
 
 namespace_expr = re.compile(r'^\{.*\}')
 
-_simplevalues = set([int, long, basestring, str, unicode, float])
+_simplevalues = set([int, long, float])
+_strvalues = set([basestring, str, unicode])
 
 @dispatch.generic()
 def soap_value(name, return_type, value):
@@ -34,6 +35,12 @@ def soap_value(name, return_type, value):
     SOAP response output."""
     pass
 
+@soap_value.when("type(value) in _strvalues")
+def xml_string(name, return_type, value):
+    elem = Element(name, **{"xsi:type" : "xsd:string"})
+    elem(value)
+    return elem
+ 
 @soap_value.when("type(value) in _simplevalues")
 def soapint(name, return_type, value):
     elem = Element(name, **{"xsi:type" : soap_type(return_type)})
