@@ -33,6 +33,13 @@ class ComplexProperty(object):
         return FancyValue("Arnie", 55)
     athing = typedproperty(FancyValue, athing)
 
+class ReadWriteProperty(object):
+    def setvalue(self, value):
+        self._value = value
+    def getvalue(self):
+        return self._value
+    value = typedproperty(str, getvalue, setvalue)
+
 class FoodItem(object):
     person = FancyValue
     quantity = unsigned
@@ -94,6 +101,13 @@ class ComplexService(WebServicesRoot):
         self.last_person = person
         return person
 
+    @wsexpose(ReadWriteProperty)
+    @wsvalidate(ReadWriteProperty)
+    def getandsetrwprop(self, rwp):
+        r = ReadWriteProperty()
+        r.value = rwp.value
+        return r
+
 class InnerService(WebServicesController):
     def __init__(self, add_another=False):
         if add_another:
