@@ -84,4 +84,19 @@ def test_complex_input():
     output = cherrypy.response.body[0]
     print output
     print cherrypy.root.last_person.age
-    assert cherrypy.root.last_person.age == 32
\ No newline at end of file
+    assert cherrypy.root.last_person.age == 32
+
+def test_rwprop():
+    cherrypy.root = ComplexService("http://foo.bar.baz/")
+    
+    request = """{"rwp": {"value": "AValue"}}"""
+    testutil.create_request("/getandsetrwprop", rfile=StringIO.StringIO(request), 
+                            method="POST", 
+                            headers={"Content-Length" : str(len(request)),
+                                     "Content-Type" : 
+                                        "application/json; charset=utf-8",
+                                     "Accept" : 
+                                        "application/json"})
+    output = cherrypy.response.body[0]
+    print output
+    assert output == """{"result": {"value": "AValue"}}"""
