@@ -5,7 +5,11 @@ import mimetools
 
 from turbogears import testutil, validate
 import cherrypy
-import cElementTree as et
+try:
+    # python >= 2.5
+    from xml.etree import cElementTree as et
+except ImportError:
+    import cElementTree as et
 
 from tgwebservices.controllers import WebServicesRoot, WebServicesController, \
                                       wsexpose, wsvalidate
@@ -446,4 +450,13 @@ def test_complex_input_simple_object():
     <age>280</age>
 </p>""")
     print output
-    assert isinstance(ci.person, Person)
\ No newline at end of file
+    assert isinstance(ci.person, Person)
+
+def test_rw_typedproperty():
+    ci = ComplexService("http://foo.bar.baz/")
+    cherrypy.root = ci
+    output = run_soap("getandsetrwprop", """<rwp>
+    <value>AValue</value>
+</rwp>""")
+    print output
+    assert '<getandsetrwpropResponse><result xsi:type="ReadWriteProperty"><value xsi:type="xsd:string">AValue</value></result></getandsetrwpropResponse>' in output
