@@ -33,4 +33,18 @@ def test_complex_input():
     output = cherrypy.response.body[0]
     print output
     assert output == """<result><age>32</age><computed>Hello!</computed>""" \
-                     """<name>Fred</name></result>"""
\ No newline at end of file
+                     """<name>Fred</name></result>"""
+
+def test_rwproperty():
+    cherrypy.root = ComplexService("http://foo.bar.baz/")
+    request = """<request>
+    <rwp><value>AValue</value></rwp>
+</request>"""
+    testutil.create_request("/getandsetrwprop", rfile=StringIO.StringIO(request), 
+                            method="POST", 
+                            headers={"Content-Length" : str(len(request)),
+                                     "Content-Type" : 
+                                        "text/xml; charset=utf-8"})
+    output = cherrypy.response.body[0]
+    print output
+    assert output == """<result><value>AValue</value></result>"""
